@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12132 2020-04-29 00:59:18Z Trista $
+# $Id: __init__.py 12303 2020-06-03 06:22:10Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2020-04-29 09:59:18 +0900 (週三, 29 四月 2020) $
-# $Revision: 12132 $
+# $Author: Lavender $ (last)
+# $Date: 2020-06-03 15:22:10 +0900 (週三, 03 六月 2020) $
+# $Revision: 12303 $
 
 from __future__ import print_function
 
@@ -482,21 +482,21 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         }
     }
 
-    if DEBUG:
-        loggingDefaults['LOGGING']['handlers'].update({
-            'debug_file': {
-                'level': 'DEBUG',
-                'class': 'logging.FileHandler',
-                'filename': os.path.join(projectPath, 'debug.log'),
-            },        
-        })
-        loggingDefaults['LOGGING']['loggers'].update({
-            'django': {
-                'handlers': ['debug_file'],
-                'level': 'DEBUG',
-                'propagate': True,
-            },        
-        })
+    # if DEBUG:
+        # loggingDefaults['LOGGING']['handlers'].update({
+            # 'debug_file': {
+                # 'level': 'DEBUG',
+                # 'class': 'logging.FileHandler',
+                # 'filename': os.path.join(projectPath, 'debug.log'),
+            # },        
+        # })
+        # loggingDefaults['LOGGING']['loggers'].update({
+            # 'django': {
+                # 'handlers': ['debug_file'],
+                # 'level': 'DEBUG',
+                # 'propagate': True,
+            # },        
+        # })
 
 
     update(settingsDict, loggingDefaults)
